function PrintSizeGb($value) {
    "{0:00.00}gb" -f ($value / 1GB)
}

$wmi_Win32_PerfRawData_PerfOS_Memory = Get-WmiObject Win32_PerfRawData_PerfOS_Memory
$pagefileTotal        = $wmi_Win32_PerfRawData_PerfOS_Memory.CommitLimit
$pagefileFree         = $wmi_Win32_PerfRawData_PerfOS_Memory.AvailableBytes
$pagefileUsed         = $wmi_Win32_PerfRawData_PerfOS_Memory.CommittedBytes
$kernelPoolNonpaged   = $wmi_Win32_PerfRawData_PerfOS_Memory.PoolNonpagedBytes
$kernelPoolPaged      = $wmi_Win32_PerfRawData_PerfOS_Memory.PoolPagedBytes
$kernelDriver         = $wmi_Win32_PerfRawData_PerfOS_Memory.SystemDriverTotalBytes

$usermodeProcesses    = Get-Process
$usermodeProcessesSum = ($usermodeProcesses | Measure-Object -Sum PagedMemorySize64).Sum

$pagefileUnexplained  = $pagefileUsed `
	- $kernelPoolNonpaged `
	- $kernelPoolPaged `
	- $kernelDriver `
	- $usermodeProcessesSum

Write-Host "Virtual memory summary:"
Write-Host (PrintSizeGb $pagefileTotal)        " = Total"
Write-Host (PrintSizeGb $pagefileUsed)         " = Used"
Write-Host (PrintSizeGb $pagefileFree)         " = Available"

Write-Host
Write-Host "Usage breakdown:"
Write-Host (PrintSizeGb $usermodeProcessesSum) " = Running programs"
Write-Host (PrintSizeGb $kernelPoolNonpaged)   " = Kernel Nonpaged Pool"
Write-Host (PrintSizeGb $kernelPoolPaged)      " = Kernel Paged Pool"
Write-Host (PrintSizeGb $kernelDriver)         " = Kernel Drivers"
Write-Host (PrintSizeGb $pagefileUnexplained)  " = Not explained by this script (are you running virtual machines?)"

Write-Host
Write-Host "Programs breakdown:"
$usermodeProcesses | Sort-Object -Descending PagedMemorySize64 | Foreach-Object {
	$pathOrName = if ($_.Path) { $_.Path } else { $_.Name }
	$currLine = (PrintSizeGb $_.PagedMemorySize64) + " = " + $pathOrName
	Write-Host $currLine
}
